import ColUpload from '@/components/col-upload'
import request from '@/helpers/request'
import { verifyNumberIntegerAndFloat } from '@/helpers/toolsValidate'
import {
  ElButton,
  ElCol,
  ElForm,
  ElFormItem,
  ElImage,
  ElInput,
  ElOption,
  ElRadio,
  ElRadioGroup,
  ElRow,
  ElSelect,
  ElTabPane,
  ElTabs
} from 'element-plus'
import { defineComponent } from 'vue'
import { createState } from '../createState'

export default defineComponent({
  name: 'course-info',
  computed: {
    choiceSubjectIds() {
      // 选择的科目编号
      let ids = createState.lessonGroup.lessonSubject
        ? Number(createState.lessonGroup.lessonSubject)
        : null
      return ids ? [ids] : []
    },
    subjectList() {
      // 学科列表
      return createState.subjectList || []
    },
    lessonSubjectName() {
      // 选择的科目
      let tempStr = ''
      this.subjectList.forEach((item: any) => {
        if (this.choiceSubjectIds.includes(item.id)) {
          tempStr = item.name
        }
      })
      return tempStr
    },
    calcRatePrice() {
      // 计算手续费
      let rate = createState.rate || 0
      let price = createState.lessonGroup.lessonPrice || 0
      return (price - (rate / 100) * price).toFixed(2)
    }
  },
  async mounted() {
    try {
      if (createState.subjectList.length <= 0) {
        const res = await request.post('/api-website/teacher/querySubject')
        createState.subjectList = res.data || []
      }
    } catch {
      //
    }
  },
  methods: {
    onFormatter(val: any) {
      return verifyNumberIntegerAndFloat(val)
    },
    tabChange(name: number) {
      ;(this as any).$refs.form.resetValidation('lessonCoverTemplateUrl')
      ;(this as any).$refs.form.resetValidation('lessonCoverUrl')
      createState.tabIndex = name
    },
    selectImg(val: string) {
      createState.lessonGroup.lessonCoverUrl = ''
      createState.lessonGroup.lessonCoverTemplateUrl = val
    }
  },
  render() {
    return (
      <>
        <ElForm
          class="px-[200px] pb-10 pt-7"
          size="large"
          labelWidth={'90px'}
          labelPosition="left"
        >
          <ElFormItem label="课程名称">
            <ElInput placeholder="请输入课程名称" />
          </ElFormItem>
          <ElFormItem label="课程声部">
            <ElSelect class="w-full" placeholder="请选择课程声部">
              {createState.subjectList.map((item: any) => (
                <ElOption value={item.id}>{item.name}</ElOption>
              ))}
            </ElSelect>
          </ElFormItem>
          <ElFormItem label="课程介绍">
            <ElInput
              placeholder="请输入课程介绍"
              type="textarea"
              // @ts-ignore
              maxlength={200}
              rows={4}
              showWordLimit
            />
          </ElFormItem>
          <ElFormItem label="课程组售价">
            <ElInput
              placeholder="请输入课程组售价"
              formatter={this.onFormatter}
              v-slots={{
                append: () => <span class="text-base text-[#333]">元</span>
              }}
            />
          </ElFormItem>
          <div class="text-sm text-[#999] pl-[90px] leading-relaxed pb-2">
            <p>扣除手续费后您的课程预计收入为： </p>
            {/* <p>
              单课时<span class="px-1 text-[#FF4E19]">19</span>元/人
            </p> */}
            <p>
              课程组总收入
              <span class="px-1 text-[#FF4E19]">{this.calcRatePrice}</span>元/人
            </p>
            <p>您的课程收入将在课程结束后结算到您的账户中 </p>
          </div>
          <ElFormItem label="课程封面" class="!mb-0">
            <ElTabs v-model={createState.tabIndex}>
              <ElTabPane label="图片模板" name={1}></ElTabPane>
              <ElTabPane label="自定义模板" name={2}></ElTabPane>
            </ElTabs>
          </ElFormItem>
          <ElFormItem>
            {/* <ElRadioGroup>
              <ElRow>
                {createState.templateList.map((item: any) => (
                  <ElCol span={10} class="mb-3 cursor-pointer">
                    <div class="w-40 relative rounded-xl overflow-hidden border">
                      <ElImage src={item} class="align-middle" />
                      <ElRadio
                        label={item}
                        class="!absolute bottom-2 right-0 !h-auto"
                      >
                        {''}
                      </ElRadio>
                    </div>
                  </ElCol>
                ))}
              </ElRow>
            </ElRadioGroup> */}
            <ColUpload />
          </ElFormItem>
        </ElForm>
        <div class="border-t border-t-[#E5E5E5] text-center pt-6 pb-7">
          <ElButton
            type="primary"
            class="!w-40 !h-[38px]"
            onClick={() => {
              createState.active = 1
            }}
          >
            下一步
          </ElButton>
        </div>
      </>
    )
  }
})
